@@ -87,7 +87,7 @@ def get_BlackScholesMerton_stocks_estimation(
     else:
         for i in range(len(symbols)):
             stock_df = stocks_data_dfs[i]
-            stock_df['EffVal'] = stock_df['Close']
+            stock_df['EffVal'] = stock_df['Close'].copy()
             stocks_data_dfs[i] = stock_df
 
     logging.info('Estimating...')
